@@ -301,7 +301,7 @@ def add_dataset(dataset, skip_existing=True, insert_new=True, fields=None, expan
     raise NotImplementedError
 
 
-def create_dataset(dataset_name, dataset_type, classes=[], mask_targets={}):
+def create_dataset(dataset_name, dataset_type, version="001", classes=[], mask_targets={}):
     """Create an empty :class:`fiftyone.core.dataset.Dataset` with the name.
 
     Args:
@@ -322,7 +322,7 @@ def create_dataset(dataset_name, dataset_type, classes=[], mask_targets={}):
     info = {
         "dataset_name": dataset_name,
         "dataset_type": dataset_type,
-        "version": "001",
+        "version": version,
         "classes": classes,
         "mask_targets": mask_targets,
         "num_samples": {},
@@ -337,7 +337,7 @@ def create_dataset(dataset_name, dataset_type, classes=[], mask_targets={}):
     return dataset
 
 
-def load_images_dir(dataset_dir, dataset_name, dataset_type, classes=[], mask_targets={}):
+def load_images_dir(dataset_dir, dataset_name, dataset_type, version="001", classes=[], mask_targets={}):
     """Create a :class:`fiftyone.core.dataset.Dataset` from the given directory of images.
 
     Args:
@@ -359,7 +359,7 @@ def load_images_dir(dataset_dir, dataset_name, dataset_type, classes=[], mask_ta
     info = {
         "dataset_name": dataset_name,
         "dataset_type": dataset_type,
-        "version": "001",
+        "version": version,
         "classes": classes,
         "mask_targets": mask_targets,
         "num_samples": {},
@@ -437,6 +437,39 @@ def load_segmentation_dataset(dataset_dir, info_py="info.py", data_path="data",
     return dataset
 
 
+def export_image_dataset(export_dir, dataset, splits=None):
+    shutil.rmtree(export_dir, ignore_errors=True)
+
+    _tags = set(dataset.distinct("tags"))
+
+    if splits is None:
+        splits = ["train", "val", "test"]
+    elif splits == "auto":
+        splits = sorted(_tags)
+
+    assert isinstance(splits, list)
+    splits = [s for s in splits if s in _tags]
+
+    if not splits:
+        splits = ["train"]
+        dataset.tag_samples(splits)
+
+    for split in splits:
+        print(f"\n[{split}]\n")
+        view = dataset.match_tags(split)
+        curr_dir = Path(export_dir) / split
+
+        view.export(
+            export_dir=str(curr_dir / "data"),
+            dataset_type=fo.types.ImageDirectory,
+        )
+
+        with open(curr_dir / "README.md", "w") as f:
+            f.write("# README\n\n")
+
+    return export_dir
+
+
 def export_classification_labels(export_dir, dataset, label_field, splits=None):
     shutil.rmtree(export_dir, ignore_errors=True)
 
@@ -466,6 +499,9 @@ def export_classification_labels(export_dir, dataset, label_field, splits=None):
             include_confidence=True,
         )
 
+        with open(curr_dir / "README.md", "w") as f:
+            f.write("# README\n\n")
+
     return export_dir
 
 
@@ -499,6 +535,9 @@ def export_classification_dataset(export_dir, dataset, label_field, splits=None,
             include_confidence=True,
         )
 
+        with open(curr_dir / "README.md", "w") as f:
+            f.write("# README\n\n")
+
     return export_dir
 
 
